@@ -3,11 +3,12 @@ import os
 from ..action import ActionManager as AM
 from ..cloud import CloudCli
 from ..project import Project
+from .. import __edb_ansible_version__
 
 
 class GCloudPOTProject(Project):
 
-    ansible_collection_name = 'edb_devops.edb_postgres:3.5.2'
+    ansible_collection_name = 'edb_devops.edb_postgres:%s' % __edb_ansible_version__  # noqa
     aws_collection_name = 'community.aws:1.4.0'
 
     def __init__(self, name, env, bin_path=None):
@@ -18,6 +19,8 @@ class GCloudPOTProject(Project):
         self.terraform_path = os.path.join(self.terraform_share_path, 'gcloud')
         # POT only attributes
         self.ansible_pot_role = os.path.join(self.ansible_share_path, 'roles')
+        # Route53 entry removal playbook
+        self.ansible_route53_remove = os.path.join(self.ansible_share_path, 'POT-Remove-Project-Route53.yml')
         # TPAexec hooks path
         self.tpaexec_pot_hooks = os.path.join(self.tpaexec_share_path, 'hooks')
         self.custom_ssh_keys = {}
@@ -165,3 +168,6 @@ class GCloudPOTProject(Project):
 
     def display_inventory(self, inventory_data):
         self.pot_display_inventory(inventory_data)
+
+    def destroy(self):
+        self.pot_destroy()
